/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/widget/public/nsIMenuRollup.idl
 */

#ifndef __gen_nsIMenuRollup_h__
#define __gen_nsIMenuRollup_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsISupportsArray_h__
#include "nsISupportsArray.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMenuRollup */
#define NS_IMENUROLLUP_IID_STR "10c69225-2c5a-4948-8690-0bc589d145b4"

#define NS_IMENUROLLUP_IID \
  {0x10c69225, 0x2c5a, 0x4948, \
    { 0x86, 0x90, 0x0b, 0xc5, 0x89, 0xd1, 0x45, 0xb4 }}

class NS_NO_VTABLE nsIMenuRollup : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMENUROLLUP_IID)

  /* nsISupportsArray GetSubmenuWidgetChain (); */
  NS_IMETHOD GetSubmenuWidgetChain(nsISupportsArray **_retval) = 0;

  /* void AdjustPopupsOnWindowChange (); */
  NS_IMETHOD AdjustPopupsOnWindowChange(void) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMenuRollup, NS_IMENUROLLUP_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMENUROLLUP \
  NS_IMETHOD GetSubmenuWidgetChain(nsISupportsArray **_retval); \
  NS_IMETHOD AdjustPopupsOnWindowChange(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMENUROLLUP(_to) \
  NS_IMETHOD GetSubmenuWidgetChain(nsISupportsArray **_retval) { return _to GetSubmenuWidgetChain(_retval); } \
  NS_IMETHOD AdjustPopupsOnWindowChange(void) { return _to AdjustPopupsOnWindowChange(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMENUROLLUP(_to) \
  NS_IMETHOD GetSubmenuWidgetChain(nsISupportsArray **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSubmenuWidgetChain(_retval); } \
  NS_IMETHOD AdjustPopupsOnWindowChange(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->AdjustPopupsOnWindowChange(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMenuRollup : public nsIMenuRollup
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMENUROLLUP

  nsMenuRollup();

private:
  ~nsMenuRollup();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMenuRollup, nsIMenuRollup)

nsMenuRollup::nsMenuRollup()
{
  /* member initializers and constructor code */
}

nsMenuRollup::~nsMenuRollup()
{
  /* destructor code */
}

/* nsISupportsArray GetSubmenuWidgetChain (); */
NS_IMETHODIMP nsMenuRollup::GetSubmenuWidgetChain(nsISupportsArray **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void AdjustPopupsOnWindowChange (); */
NS_IMETHODIMP nsMenuRollup::AdjustPopupsOnWindowChange()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMenuRollup_h__ */
